pilas.fisica.ConstanteDeMovimiento

Package pilas :: Module fisica :: Class ConstanteDeMovimiento |
[hide private]
[frames] | no frames]

# Class ConstanteDeMovimiento

source code

Representa una constante de movimiento para el mouse.

Instance Methods | [hide private]
__init__(self, figura) Inicializa la constante. | source code
mover(self, x, y) Realiza un movimiento de la figura. | source code
eliminar(self) | source code

Method Details | [hide private]

### __init__(self, figura) (Constructor) | source code
Inicializa la constante. :param figura: Figura a controlar desde el mouse.

### mover(self, x, y) | source code
Realiza un movimiento de la figura. :param x: Posición horizontal. :param y: Posición vertical.